@@ -30,14 +30,18 @@ class CheckMaster:
         else:
             msg = f"{func_name} {rule}"
         if not _check:
-            logger.error(msg)
+            _level = rule.get("level", "error")
+            getattr(logger, _level)(msg)
             if self.remediations:
                 _rem = rule.get("remediation") or "no remediation message"
                 print(f"  {chr(746)} {_rem}")
-            return False
+            if _level == 'warning':
+                return _level
+            else:
+                return 'false'
         else:
             logger.info(msg)
-            return True
+            return 'true'
 
     def start(self):
         statuses = {}
@@ -50,9 +54,9 @@ class CheckMaster:
                 for rule in rules:
                     _stat = self._check(_func, func, rule, self.tags)
             else:
-                raise NotImplemented(_func)
+                raise NotImplementedError(_func)
             statuses[_func] = _stat
-        if False in statuses.values():
+        if 'false' in statuses.values():
             return False
         else:
             return True
